==> oddmuse-1.562.tar.gz: oddmuse-1.562/russian-utf8.pl <==
# UTF-8 encoded Russian language file for use with Oddmuse
#
# Copyright (c) 2003  Zajcev Evgeny
# Copyright (C) 2004  Andrei Bulava <abulava@users.sourceforge.net>
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt .
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
# This script was last checked for Oddmuse version 1.383.
#
$ModulesDescription .= '<p>$Id: russian-utf8.pl,v 1.3 2005/07/02 00:03:28 as Exp $</p>';
%Translate = split('\n',<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.

Could not create %s
Невозможно создать %s
Invalid UserName %s: not saved.
Hекорректная кличка %s: ничего не записано.
UserName must be 50 characters or less: not saved

This page contains an uploaded file:

XML::RSS is not available on this system.

diff
отличия
history
история
%s returned no data, or LWP::UserAgent is not available.

RSS parsing failed for %s

No items found in %s.

 . . . . 

Click to edit this page
Щелчок - создать эту страницу
image

download

CGI Internal error: %s

Invalid action parameter %s
Некорректный параметр действия %s
Invalid URL.
Некорректный URL.
Page name is missing

Page name is too long: %s
Имя страницы слишком велико: %s
Invalid Page %s
Некорректная страница %s
Invalid Page %s (must not end with .db)
Некорректная страница %s (не должна оканчиваться на .db)
Invalid Page %s (must not end with .lck)
Некорректная страница %s (Некорректная страница %s lck)
Page name may not contain space characters: %s
Имя страницы не может содержать пробельные символы: %s
Preview:
Предпросмотр:
Preview only, not yet saved
Только предпросмотр - пока ничего не записано
Please go on to %s.

Could not open %s log file
Не возможно открыть файл протокола %s 
Error was
Были ошибки 
Note: This error is normal if no changes have been made.
Примечание: Эта ошибка - нормально, если не было сделано изменений.
Could not open old %s log file
Не возможно открыть старый файл протокола %s 
No updates since %s
Не было обновлений с %s
Updates since %s
Обновления с %s
Updates in the last %s days
Обновления за последние %s дней
Updates in the last %s day
Обновления за последний %s день
for %s only
только для %s
List latest change per page only
Перечислить только последнее изменение на страницу
List all changes
Перечислить все изменения
List only major changes
Перечислить только значительные изменения
Include minor changes
Включить незначительные изменения
%s days
%s дней
List later changes
Перечислить недавние изменения
Filters
Фильтры
Username:
Имя пользователя:
Host:
Хост:
Language:

Go!
Вперёд!
(minor)
(незначительные)
rollback
откат
new

from %s
с %s
History of %s
История %s
Compare
Сравнить
Revision %s
Версия %s
by

Rolling back changes

Missing target for rollback.

Target for rollback is too far back.

Rollback to %s

%s rolled back

Index of all pages
Каталог всех страниц:
Wiki Version

Unlock Wiki

Recent Visitors

Password
Пароль
Run maintenance

Unlock site

Lock site

Unlock %s

Lock %s

Administration

Actions:

Important pages:

To mark a page for deletion, put <strong>%s</strong> on the first line.

[Home]
[Домой]
redirected from %s
перенаправлено с %s
Click to search for references to this page
Щелчок - искать ссылки на эту страницу
Cookie: 

Warning
Внимание
Database is stored in temporary directory %s
База данных сохранена во временной директории %s
%s seconds

The same page on other sites:

EditNearLinks

Last edited
Последнее редактирование
Edited
Правленное
by %s

(diff)
(отличия)
Edit revision %s of this page
Править версию %s этой страницы
Edit this page
Редактировать текст этой страницы
e

This page is read-only
Эта страница предназначена только для чтения
View other revisions
Смотреть другие версии
View current revision
Смотреть текущую версию
View all changes
Смотреть все изменения
Homepage URL:

s

Save
Сохранить
Preview
Предпросмотр
Search:
Поиск:
f

Replace:
Замена:
Validate HTML

Validate CSS

Difference (from revision %1 to %2)
Отличия (от версии %1 до %2)
revision %s
версии %s
current revision
текущей версии
Difference (from prior %s revision)
Отличия (текущей версии от предыдущей - %s)
major
значительные
minor
незначительные
No diff available.
Отличий нет.
Old revision:

Changed:
Изменилось:
Removed:
Удалено:
Added:
Добавлено:
to

Revision %s not available
Версия %s не доступна
showing current revision instead
отображение текущей версии вместо
Showing revision %s
Показ версии %s
Cannot save a nameless page.

Cannot save a page without revision.

Cannot open %s

Cannot write %s

Cannot create %s

Could not get %s lock

This operation may take several seconds...
Это может занять несколько секунд, так что не нервничайте
Forced unlock of %s lock.

No unlock required.

%s hours ago

1 hour ago

%s minutes ago

1 minute ago

%s seconds ago

1 second ago

just now

Editing Denied
Редактирование запрещено
Editing not allowed: user, ip, or network is blocked.
Редактирование не разрешено: пользователь, IP или сеть заблокированы.
Contact the wiki administrator for more information.
Свяжитесь с нашей администрацией чтоб узнать больше.
The rule %s matched for you.

See %s for more information.

Editing not allowed: %s is read-only.
Редактирование не допустимо: %s только для чтения.
Only administrators can upload files.

Editing revision %s of
Редактирование версии %s
Editing %s
Редактирование %s
Editing old revision %s.
Редактирование старой версии %s.
Saving this page will replace the latest revision with this text.
Сохранение этой страницы заменит последнюю версию на этот текст.
Summary:
Итого:
This change is a minor edit.
Это изменение является незначительной правкой.
Replace this file with text.
Заменить этот файл текстом.
Replace this text with a file.
Заменить этот текст файлом.
File to upload: 

Files of type %s are not allowed.

Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
Ваш пароль сохраняется в cookie, если cookies у вас включены. Cookies могут быть потеряны, если вы подключаетесь с другого компьютера, с другой учётной записи, или используя другое программное обеспечение.
You are currently an administrator on this site.
Теперь вы - администратор на этом сайте.
You are currently an editor on this site.
Теперь вы - редактор на этом сайте.
You are a normal user on this site.
Вы - обычный пользователь на этом сайте.
Your password does not match any of the  administrator or editor passwords.
Ваш пароль не совпадает с паролями администратора или редактора.
Password:
Пароль:
This site does not use admin or editor passwords.
Этот сайт не использует пароли администратора или редактора.
This operation is restricted to site editors only...
Эта операция только для редакторов сайта...
This operation is restricted to administrators only...
Эта операция только для администаторов сайта...
Rule "%1" matched "%2" on this page.

Without normal pages

Include normal pages

Without permanent anchors

Include permanent anchors

Without near pages

Include near pages

(for %s)
(%s)
%s pages found.
Найдено %s страниц.
Replaced: %s

Search for: %s
Искать: %s
View changes for these pages
Смотреть изменения этих страниц
Search sites on the %s as well

and

or

Fetching results from %s:

Near pages:

last updated

Complete Content

The main page is %s.

Comments on this page
Комментарии к этой странице
Editing not allowed for %s.
Редактирование не разрешено для %s.
SampleUndefinedPage
ПримерПроизвольнойСтраницы
%s cannot be defined.
%s невозможно определить.
Sample_Undefined_Page
Пример_Произвольной_Страницы
[[%s]] cannot be defined.
[[%s]] невозможно определить
Only an administrator can create %s.

Transfer Error: %s

Browser reports no file info.

Browser reports no file type.

Edit Denied

The page contains banned text.

This page was changed by somebody else %s.

The changes conflict.  Please check the page again.

Please check whether you overwrote those changes.

Anonymous

Cannot delete the index file %s.

Please check the directory permissions.

Your changes were not saved.

Could not get a lock to merge!

you

ancestor

other

Run Maintenance

Maintenance not done.

(Maintenance can only be done once every 12 hours.)

Remove the "maintain" file or wait.

Main lock obtained.

Expiring keep files and deleting pages marked for deletion

not deleted: 

deleted

Moving part of the %s log file.

Moving %s log entries.

Getting page index file for %s.

Main lock released.

Set or Remove global edit lock

Edit lock created.

Edit lock removed.

Set or Remove page edit lock

Missing page id to lock/unlock...

Lock for %s created.

Lock for %s removed.

Displaying Wiki Version

Show dependencies

Inter links:

Near links:

Show parsed link data

Too many connections by %s

Please do not fetch more than %1 pages in %2 seconds.

Check whether the web server can create the directory %s and whether it can create files in it.

anchor first defined here: %s

Click to search for references to this permanent anchor

the page %s also exists

Deleting %s

Deleted %s

Renaming %1 to %2.

The page %s does not exist

The page %s already exists

Cannot rename %1 to %2

Renamed to %s

Renamed from %s

Renamed %1 to %2.

Immediately delete %s

Rename %s to:

Cannot highlight the language %s.

Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.

The match parameter is missing.

Page Collection for %s

Previous

Next

Calendar %s

Clustermap

Pages without a Cluster

Comments on 

Comment on 

Compilation for %s

Compilation tag is missing a regular expression.

Despamming pages

Cannot find revision %s.

Revert to revision %1: %2

Marked as %s.

Cannot find unspammed revision.

Footnotes:

Could not find %1.html template in %2

image: %s

Index

Languages:

Show!

Define

Full Link List
Полный список ссылок
Template without parameters

The template %s is either empty or does not exist.

Register for %s

Please choose a username of the form "FirstLast" using your real name.

The passwords do not match.

The password must be at least %s characters.

That email address is invalid.

The username %s has already been registered.

Your registration for %s has been submitted.

  Please allow time for the webmaster to approve your request.

An account was created for %s.

Login to %s

Username and/or password are incorrect.

Logged in as %s.

Logout of %s

Logout of %s?

Logged out of %s

You are now logged out.

Register a new account

Login

Logout

Clearing Cache

Done.

Generating Link Database

The 404 handler extension requires the link data extension (links.pl).

LocalMap

No page id for action localmap

Requested page %s does not exist

Local Map for %s

view

Orphan List

Trail: 

None

Type

Permalink to "%s"

Portrait

You did not answer correctly.

All Referrers

Referrers

Rebuild index for searching

Rebuilding Index

Search::FreeText is not available on this system.

Rebuilding index not done.

(Rebuilding the index can only be done once every 12 hours.)

Search term missing.

Result pages: 

(%s results)

Slideshow:%s

Static Copy

Back to %s
Назад к %s
Tag

Alternatively, use one of the following templates:

Thread: %s

ID parameter is missing.

Thread %s does not exist.

Page %s does not contain a thread.

Add

URL parameter is missing.

Add to %s thread

Below:

URL:

Name:

Failed to remove %s

Contents

This page is a translation of %s. 

The translation is up to date.

The translation is outdated.

The page does not exist.

http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s

http://www.amazon.com/exec/obidos/ISBN=%s

alternate
альтернативный
http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search
поиск
Blog

END_OF_TRANSLATION

==> oddmuse-1.632.tar.gz: oddmuse-1.632/russian-utf8.pl <==
# UTF-8 encoded Russian language file for use with Oddmuse
#
# Copyright (c) 2003  Zajcev Evgeny
# Copyright (C) 2004  Andrei Bulava <abulava@users.sourceforge.net>
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt .
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
# This script was last checked for Oddmuse version 1.383.
#
$ModulesDescription .= '<p>$Id: russian-utf8.pl,v 1.6 2005/10/09 12:48:35 as Exp $</p>';
%Translate = split(/\n/,<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.

Could not create %s
Невозможно создать %s
Invalid UserName %s: not saved.
Hекорректная кличка %s: ничего не записано.
UserName must be 50 characters or less: not saved

This page contains an uploaded file:

XML::RSS is not available on this system.

diff
отличия
history
история
%s returned no data, or LWP::UserAgent is not available.

RSS parsing failed for %s

No items found in %s.

 . . . . 

Click to edit this page
Щелчок - создать эту страницу
image

download

CGI Internal error: %s

Invalid action parameter %s
Некорректный параметр действия %s
Invalid URL.
Некорректный URL.
Page name is missing

Page name is too long: %s
Имя страницы слишком велико: %s
Invalid Page %s
Некорректная страница %s
Invalid Page %s (must not end with .db)
Некорректная страница %s (не должна оканчиваться на .db)
Invalid Page %s (must not end with .lck)
Некорректная страница %s (Некорректная страница %s lck)
Page name may not contain space characters: %s
Имя страницы не может содержать пробельные символы: %s
Preview:
Предпросмотр:
Preview only, not yet saved
Только предпросмотр - пока ничего не записано
Please go on to %s.

Could not open %s log file
Не возможно открыть файл протокола %s 
Error was
Были ошибки 
Note: This error is normal if no changes have been made.
Примечание: Эта ошибка - нормально, если не было сделано изменений.
Could not open old %s log file
Не возможно открыть старый файл протокола %s 
No updates since %s
Не было обновлений с %s
Updates since %s
Обновления с %s
Updates in the last %s days
Обновления за последние %s дней
Updates in the last %s day
Обновления за последний %s день
for %s only
только для %s
List latest change per page only
Перечислить только последнее изменение на страницу
List all changes
Перечислить все изменения
List only major changes
Перечислить только значительные изменения
Include minor changes
Включить незначительные изменения
%s days
%s дней
List later changes
Перечислить недавние изменения
Filters
Фильтры
Title:

Title and Body:

Username:
Имя пользователя:
Host:
Хост:
Language:

Go!
Вперёд!
(minor)
(незначительные)
rollback
откат
new

from %s
с %s
This page is too big to send over RSS.

History of %s
История %s
Compare
Сравнить
Revision %s
Версия %s
by

Rolling back changes

Missing target for rollback.

Target for rollback is too far back.

Rollback to %s

%s rolled back

Index of all pages
Каталог всех страниц:
Wiki Version

Unlock Wiki

Password
Пароль
Run maintenance

Unlock site

Lock site

Install CSS

Unlock %s

Lock %s

Administration

Actions:

Important pages:

To mark a page for deletion, put <strong>%s</strong> on the first line.

[Home]
[Домой]
redirected from %s
перенаправлено с %s
Click to search for references to this page
Щелчок - искать ссылки на эту страницу
Cookie: 

Warning
Внимание
Database is stored in temporary directory %s
База данных сохранена во временной директории %s
%s seconds

The same page on other sites:

EditNearLinks

Last edited
Последнее редактирование
Edited
Правленное
by %s

(diff)
(отличия)
Edit revision %s of this page
Править версию %s этой страницы
Edit this page
Редактировать текст этой страницы
e

This page is read-only
Эта страница предназначена только для чтения
View other revisions
Смотреть другие версии
View current revision
Смотреть текущую версию
View all changes
Смотреть все изменения
Homepage URL:

s

Save
Сохранить
Preview
Предпросмотр
Search:
Поиск:
f

Replace:
Замена:
Validate HTML

Validate CSS

Difference (from revision %1 to %2)
Отличия (от версии %1 до %2)
revision %s
версии %s
current revision
текущей версии
Difference (from prior %s revision)
Отличия (текущей версии от предыдущей - %s)
major
значительные
minor
незначительные
No diff available.
Отличий нет.
The two revisions are the same.

Old revision:

Changed:
Изменилось:
Removed:
Удалено:
Added:
Добавлено:
to

Revision %s not available
Версия %s не доступна
showing current revision instead
отображение текущей версии вместо
Showing revision %s
Показ версии %s
Cannot save a nameless page.

Cannot save a page without revision.

Cannot open %s

Cannot write %s

Cannot create %s

Could not get %s lock

This operation may take several seconds...
Это может занять несколько секунд, так что не нервничайте
Forced unlock of %s lock.

No unlock required.

%s hours ago

1 hour ago

%s minutes ago

1 minute ago

%s seconds ago

1 second ago

just now

Edit Denied

Editing not allowed: user, ip, or network is blocked.
Редактирование не разрешено: пользователь, IP или сеть заблокированы.
Contact the wiki administrator for more information.
Свяжитесь с нашей администрацией чтоб узнать больше.
The rule %s matched for you.

See %s for more information.

Editing not allowed: %s is read-only.
Редактирование не допустимо: %s только для чтения.
Only administrators can upload files.

Editing revision %s of
Редактирование версии %s
Editing %s
Редактирование %s
Editing old revision %s.
Редактирование старой версии %s.
Saving this page will replace the latest revision with this text.
Сохранение этой страницы заменит последнюю версию на этот текст.
Summary:
Итого:
This change is a minor edit.
Это изменение является незначительной правкой.
Replace this file with text.
Заменить этот файл текстом.
Replace this text with a file.
Заменить этот текст файлом.
File to upload: 

Files of type %s are not allowed.

Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
Ваш пароль сохраняется в cookie, если cookies у вас включены. Cookies могут быть потеряны, если вы подключаетесь с другого компьютера, с другой учётной записи, или используя другое программное обеспечение.
You are currently an administrator on this site.
Теперь вы - администратор на этом сайте.
You are currently an editor on this site.
Теперь вы - редактор на этом сайте.
You are a normal user on this site.
Вы - обычный пользователь на этом сайте.
Your password does not match any of the  administrator or editor passwords.
Ваш пароль не совпадает с паролями администратора или редактора.
Password:
Пароль:
This site does not use admin or editor passwords.
Этот сайт не использует пароли администратора или редактора.
This operation is restricted to site editors only...
Эта операция только для редакторов сайта...
This operation is restricted to administrators only...
Эта операция только для администаторов сайта...
Rule "%1" matched "%2" on this page.

Without normal pages

Include normal pages

Without permanent anchors

Include permanent anchors

Without near pages

Include near pages

(for %s)
(%s)
Filter:

%s pages found.
Найдено %s страниц.
Replaced: %s

Search for: %s
Искать: %s
View changes for these pages
Смотреть изменения этих страниц
Search sites on the %s as well

and

or

Fetching results from %s:

Near pages:

last updated

Complete Content

The main page is %s.

Comments on this page
Комментарии к этой странице
Editing not allowed for %s.
Редактирование не разрешено для %s.
SampleUndefinedPage
ПримерПроизвольнойСтраницы
%s cannot be defined.
%s невозможно определить.
Sample_Undefined_Page
Пример_Произвольной_Страницы
[[%s]] cannot be defined.
[[%s]] невозможно определить
Only an administrator can create %s.

Transfer Error: %s

Browser reports no file info.

Browser reports no file type.

The page contains banned text.

No changes to be saved.

This page was changed by somebody else %s.

The changes conflict.  Please check the page again.

Please check whether you overwrote those changes.

Anonymous

Cannot delete the index file %s.

Please check the directory permissions.

Your changes were not saved.

Could not get a lock to merge!

you

ancestor

other

Run Maintenance

Maintenance not done.

(Maintenance can only be done once every 12 hours.)

Remove the "maintain" file or wait.

Main lock obtained.

Expiring keep files and deleting pages marked for deletion

not deleted: 

deleted

Moving part of the %s log file.

Moving %s log entries.

Getting page index file for %s.

Main lock released.

Set or Remove global edit lock

Edit lock created.

Edit lock removed.

Set or Remove page edit lock

Missing page id to lock/unlock...

Lock for %s created.

Lock for %s removed.

Displaying Wiki Version

Show dependencies

Inter links:

Near links:

Show parsed link data

Too many connections by %s

Please do not fetch more than %1 pages in %2 seconds.

Check whether the web server can create the directory %s and whether it can create files in it.

anchor first defined here: %s

Click to search for references to this permanent anchor

the page %s also exists

Copy one of the following stylesheets to %s:

Deleting %s

Deleted %s

Renaming %1 to %2.

The page %s does not exist

The page %s already exists

Cannot rename %1 to %2

Renamed to %s

Renamed from %s

Renamed %1 to %2.

Immediately delete %s

Rename %s to:

Cannot highlight the language %s.

Recent Visitors

some action

was here

and read

Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.

The match parameter is missing.

Page Collection for %s

Previous

Next

Calendar %s

Clustermap

Pages without a Cluster

Comments on 

Comment on 

Compilation for %s

Compilation tag is missing a regular expression.

Despamming pages

Cannot find revision %s.

Revert to revision %1: %2

Marked as %s.

Cannot find unspammed revision.

Add Comment

ordinary changes

Footnotes:

Could not find %1.html template in %2

Only Editors are allowed to see hidden pages.

Only Admins are allowed to see hidden pages.

image: %s

Index

Languages:

Show!

Define

Full Link List
Полный список ссылок
Template without parameters

The template %s is either empty or does not exist.

Register for %s

Please choose a username of the form "FirstLast" using your real name.

The passwords do not match.

The password must be at least %s characters.

That email address is invalid.

The username %s has already been registered.

Your registration for %s has been submitted.

  Please allow time for the webmaster to approve your request.

  An email has been sent to "%s" with further instructions.

There was an error saving your registration.

An account was created for %s.

Login to %s

Username and/or password are incorrect.

Logged in as %s.

Logout of %s

<p>Logout of %s?</p>

Logged out of %s

You are now logged out.

Register a new account

Login

Logout

Who am I?

Forgot your password?

Change your password

Approve pending registrations

Confirm Registration for %s

%s, your registration has been approved. You can now use your password to login and edit this wiki.

Confirmation failed.  Please email %s for help.

Who Am I?

You are logged in as %s.

You are not logged in.

Reset Password

The password for %s was reset.  It has been emailed to the address on file.

There was an error resetting the password for %s

The username "%s" does not exist.

Reset Password for %s

<p>Reset Password?</p>

Change Password for %s

<p>Change Password?</p>

Your current password is incorrect.

Your password has been changed.

Approve Pending Registrations for %s

%s has been approved.

There was an error approving %s.

<ul>

<li>%1 - %2</li>

</ul>

There are no pending registrations.

Clearing Cache

Done.

Generating Link Database

The 404 handler extension requires the link data extension (links.pl).

LocalMap

No page id for action localmap

Requested page %s does not exist

Local Map for %s

view

Self-ban by %s

You have banned your own IP.

Orphan List

Trail: 

None

Type

Permalink to "%s"

Portrait

You did not answer correctly.

All Referrers

Referrers

Rebuild index for searching

Rebuilding Index

Search::FreeText is not available on this system.

Rebuilding index not done.

(Rebuilding the index can only be done once every 12 hours.)

Search term missing.

Result pages: 

(%s results)

Slideshow:%s

Static Copy

Back to %s
Назад к %s
Copy to %1 succeeded: %2.

Copy to %1 failed: %2.

Tag

Alternatively, use one of the following templates:

Thread: %s

ID parameter is missing.

Thread %s does not exist.

Page %s does not contain a thread.

Add

URL parameter is missing.

Add to %s thread

Below:

URL:

Name:

Failed to remove %s

Contents

This page is a translation of %s. 

The translation is up to date.

The translation is outdated.

The page does not exist.

http://search.barnesandnoble.com/booksearch/isbninquiry.asp?ISBN=%s

http://www.amazon.com/exec/obidos/ISBN=%s

alternate
альтернативный
http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search
поиск
Upload of %s file

Blog

Matching pages:

New

Edit %s.

END_OF_TRANSLATION
